@@ -16,5 +16,5 @@ __attribute__((section(".gnu.linkonce.this_module"))) = {
 static const char __module_depends[]
 __attribute_used__
 __attribute__((section(".modinfo"))) =
-"depends=bttv,dvb-core,lgdt330x,sp887x,dst_ca,dst,or51211,nxt6000,cx24110,mt352,dvb-pll,firmware_class,i2c-core,bt878";
+"depends=bttv,dvb-core,zl10353,lgdt330x,sp887x,mt352,dst_ca,dst,or51211,cx24110,nxt6000,dvb-pll,firmware_class,i2c-core,bt878";
 
